public inbox for kvm@vger.kernel.org
 help / color / mirror / Atom feed
From: Sean Christopherson <seanjc@google.com>
To: Paolo Bonzini <pbonzini@redhat.com>
Cc: linux-kernel@vger.kernel.org, kvm@vger.kernel.org,
	Vitaly Kuznetsov <vkuznets@redhat.com>,
	Andrew Jones <drjones@redhat.com>,
	David Matlack <dmatlack@google.com>,
	Ben Gardon <bgardon@google.com>, Oliver Upton <oupton@google.com>,
	Sean Christopherson <seanjc@google.com>
Subject: [PATCH 094/128] KVM: selftests: Rename vm_vcpu_add* helpers to better show relationships
Date: Wed,  4 May 2022 22:48:40 +0000	[thread overview]
Message-ID: <20220504224914.1654036-95-seanjc@google.com> (raw)
In-Reply-To: <20220504224914.1654036-1-seanjc@google.com>

Rename vm_vcpu_add() to __vm_vcpu_add(), and vm_vcpu_add_default() to
vm_vcpu_add() to show the relationship between the newly minted
vm_vcpu_add() and __vm_vcpu_add().

Signed-off-by: Sean Christopherson <seanjc@google.com>
---
 tools/testing/selftests/kvm/aarch64/get-reg-list.c     |  2 +-
 tools/testing/selftests/kvm/aarch64/psci_cpu_on_test.c |  4 ++--
 .../testing/selftests/kvm/aarch64/vcpu_width_config.c  |  8 ++++----
 tools/testing/selftests/kvm/aarch64/vgic_init.c        | 10 +++++-----
 tools/testing/selftests/kvm/dirty_log_test.c           |  2 +-
 tools/testing/selftests/kvm/hardware_disable_test.c    |  2 +-
 .../testing/selftests/kvm/include/aarch64/processor.h  |  5 ++---
 tools/testing/selftests/kvm/include/kvm_util_base.h    |  7 +++----
 tools/testing/selftests/kvm/kvm_binary_stats_test.c    |  2 +-
 tools/testing/selftests/kvm/kvm_create_max_vcpus.c     |  2 +-
 tools/testing/selftests/kvm/lib/aarch64/processor.c    |  9 ++++-----
 tools/testing/selftests/kvm/lib/kvm_util.c             |  6 +++---
 tools/testing/selftests/kvm/lib/riscv/processor.c      |  2 +-
 tools/testing/selftests/kvm/lib/s390x/processor.c      |  2 +-
 tools/testing/selftests/kvm/lib/x86_64/processor.c     |  2 +-
 tools/testing/selftests/kvm/set_memory_region_test.c   |  2 +-
 tools/testing/selftests/kvm/steal_time.c               |  2 +-
 .../selftests/kvm/x86_64/pmu_event_filter_test.c       |  2 +-
 tools/testing/selftests/kvm/x86_64/set_boot_cpu_id.c   |  4 ++--
 tools/testing/selftests/kvm/x86_64/set_sregs_test.c    |  2 +-
 tools/testing/selftests/kvm/x86_64/sev_migrate_tests.c |  8 ++++----
 tools/testing/selftests/kvm/x86_64/tsc_scaling_sync.c  |  4 ++--
 tools/testing/selftests/kvm/x86_64/xapic_ipi_test.c    |  2 +-
 23 files changed, 44 insertions(+), 47 deletions(-)

diff --git a/tools/testing/selftests/kvm/aarch64/get-reg-list.c b/tools/testing/selftests/kvm/aarch64/get-reg-list.c
index d647973aeb30..8283a62e16e4 100644
--- a/tools/testing/selftests/kvm/aarch64/get-reg-list.c
+++ b/tools/testing/selftests/kvm/aarch64/get-reg-list.c
@@ -413,7 +413,7 @@ static void run_test(struct vcpu_config *c)
 
 	vm = vm_create_barebones();
 	prepare_vcpu_init(c, &init);
-	aarch64_vcpu_add_default(vm, 0, &init, NULL);
+	aarch64_vcpu_add(vm, 0, &init, NULL);
 	finalize_vcpu(vm, 0, c);
 
 	reg_list = vcpu_get_reg_list(vm, 0);
diff --git a/tools/testing/selftests/kvm/aarch64/psci_cpu_on_test.c b/tools/testing/selftests/kvm/aarch64/psci_cpu_on_test.c
index d60c1ddf8870..ffea4f3634b3 100644
--- a/tools/testing/selftests/kvm/aarch64/psci_cpu_on_test.c
+++ b/tools/testing/selftests/kvm/aarch64/psci_cpu_on_test.c
@@ -82,13 +82,13 @@ int main(void)
 	vm_ioctl(vm, KVM_ARM_PREFERRED_TARGET, &init);
 	init.features[0] |= (1 << KVM_ARM_VCPU_PSCI_0_2);
 
-	aarch64_vcpu_add_default(vm, VCPU_ID_SOURCE, &init, guest_main);
+	aarch64_vcpu_add(vm, VCPU_ID_SOURCE, &init, guest_main);
 
 	/*
 	 * make sure the target is already off when executing the test.
 	 */
 	init.features[0] |= (1 << KVM_ARM_VCPU_POWER_OFF);
-	aarch64_vcpu_add_default(vm, VCPU_ID_TARGET, &init, guest_main);
+	aarch64_vcpu_add(vm, VCPU_ID_TARGET, &init, guest_main);
 
 	get_reg(vm, VCPU_ID_TARGET, KVM_ARM64_SYS_REG(SYS_MPIDR_EL1), &target_mpidr);
 	vcpu_args_set(vm, VCPU_ID_SOURCE, 1, target_mpidr & MPIDR_HWID_BITMASK);
diff --git a/tools/testing/selftests/kvm/aarch64/vcpu_width_config.c b/tools/testing/selftests/kvm/aarch64/vcpu_width_config.c
index 1757f44dd3e2..1dd856a58f5d 100644
--- a/tools/testing/selftests/kvm/aarch64/vcpu_width_config.c
+++ b/tools/testing/selftests/kvm/aarch64/vcpu_width_config.c
@@ -26,12 +26,12 @@ static int add_init_2vcpus(struct kvm_vcpu_init *init1,
 
 	vm = vm_create_barebones();
 
-	vm_vcpu_add(vm, 0);
+	__vm_vcpu_add(vm, 0);
 	ret = __vcpu_ioctl(vm, 0, KVM_ARM_VCPU_INIT, init1);
 	if (ret)
 		goto free_exit;
 
-	vm_vcpu_add(vm, 1);
+	__vm_vcpu_add(vm, 1);
 	ret = __vcpu_ioctl(vm, 1, KVM_ARM_VCPU_INIT, init2);
 
 free_exit:
@@ -51,8 +51,8 @@ static int add_2vcpus_init_2vcpus(struct kvm_vcpu_init *init1,
 
 	vm = vm_create_barebones();
 
-	vm_vcpu_add(vm, 0);
-	vm_vcpu_add(vm, 1);
+	__vm_vcpu_add(vm, 0);
+	__vm_vcpu_add(vm, 1);
 
 	ret = __vcpu_ioctl(vm, 0, KVM_ARM_VCPU_INIT, init1);
 	if (ret)
diff --git a/tools/testing/selftests/kvm/aarch64/vgic_init.c b/tools/testing/selftests/kvm/aarch64/vgic_init.c
index 0329aa04da31..32dac03f5600 100644
--- a/tools/testing/selftests/kvm/aarch64/vgic_init.c
+++ b/tools/testing/selftests/kvm/aarch64/vgic_init.c
@@ -314,7 +314,7 @@ static void test_vgic_then_vcpus(uint32_t gic_dev_type)
 
 	/* Add the rest of the VCPUs */
 	for (i = 1; i < NR_VCPUS; ++i)
-		vm_vcpu_add_default(v.vm, i, guest_code);
+		vm_vcpu_add(v.vm, i, guest_code);
 
 	ret = run_vcpu(v.vm, 3);
 	TEST_ASSERT(ret == -EINVAL, "dist/rdist overlap detected on 1st vcpu run");
@@ -402,17 +402,17 @@ static void test_v3_typer_accesses(void)
 
 	v.gic_fd = kvm_create_device(v.vm, KVM_DEV_TYPE_ARM_VGIC_V3);
 
-	vm_vcpu_add_default(v.vm, 3, guest_code);
+	vm_vcpu_add(v.vm, 3, guest_code);
 
 	ret = v3_redist_reg_get(v.gic_fd, 1, GICR_TYPER, &val);
 	TEST_ASSERT(ret && errno == EINVAL, "attempting to read GICR_TYPER of non created vcpu");
 
-	vm_vcpu_add_default(v.vm, 1, guest_code);
+	vm_vcpu_add(v.vm, 1, guest_code);
 
 	ret = v3_redist_reg_get(v.gic_fd, 1, GICR_TYPER, &val);
 	TEST_ASSERT(ret && errno == EBUSY, "read GICR_TYPER before GIC initialized");
 
-	vm_vcpu_add_default(v.vm, 2, guest_code);
+	vm_vcpu_add(v.vm, 2, guest_code);
 
 	kvm_device_attr_set(v.gic_fd, KVM_DEV_ARM_VGIC_GRP_CTRL,
 			    KVM_DEV_ARM_VGIC_CTRL_INIT, NULL);
@@ -576,7 +576,7 @@ static void test_v3_redist_ipa_range_check_at_vcpu_run(void)
 
 	/* Add the rest of the VCPUs */
 	for (i = 1; i < NR_VCPUS; ++i)
-		vm_vcpu_add_default(v.vm, i, guest_code);
+		vm_vcpu_add(v.vm, i, guest_code);
 
 	kvm_device_attr_set(v.gic_fd, KVM_DEV_ARM_VGIC_GRP_CTRL,
 			    KVM_DEV_ARM_VGIC_CTRL_INIT, NULL);
diff --git a/tools/testing/selftests/kvm/dirty_log_test.c b/tools/testing/selftests/kvm/dirty_log_test.c
index ff3bd4c941a4..b61af23ba434 100644
--- a/tools/testing/selftests/kvm/dirty_log_test.c
+++ b/tools/testing/selftests/kvm/dirty_log_test.c
@@ -679,7 +679,7 @@ static struct kvm_vm *create_vm(enum vm_guest_mode mode, uint32_t vcpuid,
 	vm = __vm_create(mode, DEFAULT_GUEST_PHY_PAGES + extra_pg_pages);
 
 	log_mode_create_vm_done(vm);
-	vm_vcpu_add_default(vm, vcpuid, guest_code);
+	vm_vcpu_add(vm, vcpuid, guest_code);
 	return vm;
 }
 
diff --git a/tools/testing/selftests/kvm/hardware_disable_test.c b/tools/testing/selftests/kvm/hardware_disable_test.c
index ccbbf8783e2d..31f6d408419f 100644
--- a/tools/testing/selftests/kvm/hardware_disable_test.c
+++ b/tools/testing/selftests/kvm/hardware_disable_test.c
@@ -108,7 +108,7 @@ static void run_test(uint32_t run)
 
 	pr_debug("%s: [%d] start vcpus\n", __func__, run);
 	for (i = 0; i < VCPU_NUM; ++i) {
-		vm_vcpu_add_default(vm, i, guest_code);
+		vm_vcpu_add(vm, i, guest_code);
 		payloads[i].vm = vm;
 		payloads[i].index = i;
 
diff --git a/tools/testing/selftests/kvm/include/aarch64/processor.h b/tools/testing/selftests/kvm/include/aarch64/processor.h
index 5999e7ae7b29..f64607c136df 100644
--- a/tools/testing/selftests/kvm/include/aarch64/processor.h
+++ b/tools/testing/selftests/kvm/include/aarch64/processor.h
@@ -64,9 +64,8 @@ static inline void set_reg(struct kvm_vm *vm, uint32_t vcpuid, uint64_t id, uint
 }
 
 void aarch64_vcpu_setup(struct kvm_vm *vm, uint32_t vcpuid, struct kvm_vcpu_init *init);
-struct kvm_vcpu *aarch64_vcpu_add_default(struct kvm_vm *vm, uint32_t vcpu_id,
-					  struct kvm_vcpu_init *init,
-					  void *guest_code);
+struct kvm_vcpu *aarch64_vcpu_add(struct kvm_vm *vm, uint32_t vcpu_id,
+				  struct kvm_vcpu_init *init, void *guest_code);
 
 struct ex_regs {
 	u64 regs[31];
diff --git a/tools/testing/selftests/kvm/include/kvm_util_base.h b/tools/testing/selftests/kvm/include/kvm_util_base.h
index de36e7e91796..02df9a794530 100644
--- a/tools/testing/selftests/kvm/include/kvm_util_base.h
+++ b/tools/testing/selftests/kvm/include/kvm_util_base.h
@@ -280,7 +280,7 @@ void vm_userspace_mem_region_add(struct kvm_vm *vm,
 void vm_mem_region_set_flags(struct kvm_vm *vm, uint32_t slot, uint32_t flags);
 void vm_mem_region_move(struct kvm_vm *vm, uint32_t slot, uint64_t new_gpa);
 void vm_mem_region_delete(struct kvm_vm *vm, uint32_t slot);
-struct kvm_vcpu *vm_vcpu_add(struct kvm_vm *vm, uint32_t vcpuid);
+struct kvm_vcpu *__vm_vcpu_add(struct kvm_vm *vm, uint32_t vcpuid);
 vm_vaddr_t vm_vaddr_alloc(struct kvm_vm *vm, size_t sz, vm_vaddr_t vaddr_min);
 vm_vaddr_t vm_vaddr_alloc_pages(struct kvm_vm *vm, int nr_pages);
 vm_vaddr_t vm_vaddr_alloc_page(struct kvm_vm *vm);
@@ -658,9 +658,8 @@ static inline void vcpu_dump(FILE *stream, struct kvm_vm *vm, uint32_t vcpuid,
 struct kvm_vcpu *vm_arch_vcpu_add(struct kvm_vm *vm, uint32_t vcpu_id,
 				  void *guest_code);
 
-static inline struct kvm_vcpu *vm_vcpu_add_default(struct kvm_vm *vm,
-						   uint32_t vcpu_id,
-						   void *guest_code)
+static inline struct kvm_vcpu *vm_vcpu_add(struct kvm_vm *vm, uint32_t vcpu_id,
+					   void *guest_code)
 {
 	return vm_arch_vcpu_add(vm, vcpu_id, guest_code);
 }
diff --git a/tools/testing/selftests/kvm/kvm_binary_stats_test.c b/tools/testing/selftests/kvm/kvm_binary_stats_test.c
index edeb08239036..407e9ea8e6f3 100644
--- a/tools/testing/selftests/kvm/kvm_binary_stats_test.c
+++ b/tools/testing/selftests/kvm/kvm_binary_stats_test.c
@@ -223,7 +223,7 @@ int main(int argc, char *argv[])
 	for (i = 0; i < max_vm; ++i) {
 		vms[i] = vm_create_barebones();
 		for (j = 0; j < max_vcpu; ++j)
-			vm_vcpu_add(vms[i], j);
+			__vm_vcpu_add(vms[i], j);
 	}
 
 	/* Check stats read for every VM and VCPU */
diff --git a/tools/testing/selftests/kvm/kvm_create_max_vcpus.c b/tools/testing/selftests/kvm/kvm_create_max_vcpus.c
index acc92703f563..3ae0237e96b2 100644
--- a/tools/testing/selftests/kvm/kvm_create_max_vcpus.c
+++ b/tools/testing/selftests/kvm/kvm_create_max_vcpus.c
@@ -32,7 +32,7 @@ void test_vcpu_creation(int first_vcpu_id, int num_vcpus)
 
 	for (i = first_vcpu_id; i < first_vcpu_id + num_vcpus; i++)
 		/* This asserts that the vCPU was created. */
-		vm_vcpu_add(vm, i);
+		__vm_vcpu_add(vm, i);
 
 	kvm_vm_free(vm);
 }
diff --git a/tools/testing/selftests/kvm/lib/aarch64/processor.c b/tools/testing/selftests/kvm/lib/aarch64/processor.c
index 089e6de2160c..35bec85f43b0 100644
--- a/tools/testing/selftests/kvm/lib/aarch64/processor.c
+++ b/tools/testing/selftests/kvm/lib/aarch64/processor.c
@@ -314,16 +314,15 @@ void vcpu_arch_dump(FILE *stream, struct kvm_vm *vm, uint32_t vcpuid, uint8_t in
 		indent, "", pstate, pc);
 }
 
-struct kvm_vcpu *aarch64_vcpu_add_default(struct kvm_vm *vm, uint32_t vcpu_id,
-					  struct kvm_vcpu_init *init,
-					  void *guest_code)
+struct kvm_vcpu *aarch64_vcpu_add(struct kvm_vm *vm, uint32_t vcpu_id,
+				  struct kvm_vcpu_init *init, void *guest_code)
 {
 	size_t stack_size = vm->page_size == 4096 ?
 					DEFAULT_STACK_PGS * vm->page_size :
 					vm->page_size;
 	uint64_t stack_vaddr = vm_vaddr_alloc(vm, stack_size,
 					      DEFAULT_ARM64_GUEST_STACK_VADDR_MIN);
-	struct kvm_vcpu *vcpu = vm_vcpu_add(vm, vcpu_id);
+	struct kvm_vcpu *vcpu = __vm_vcpu_add(vm, vcpu_id);
 
 	aarch64_vcpu_setup(vm, vcpu_id, init);
 
@@ -336,7 +335,7 @@ struct kvm_vcpu *aarch64_vcpu_add_default(struct kvm_vm *vm, uint32_t vcpu_id,
 struct kvm_vcpu *vm_arch_vcpu_add(struct kvm_vm *vm, uint32_t vcpu_id,
 				  void *guest_code)
 {
-	return aarch64_vcpu_add_default(vm, vcpu_id, NULL, guest_code);
+	return aarch64_vcpu_add(vm, vcpu_id, NULL, guest_code);
 }
 
 void vcpu_args_set(struct kvm_vm *vm, uint32_t vcpuid, unsigned int num, ...)
diff --git a/tools/testing/selftests/kvm/lib/kvm_util.c b/tools/testing/selftests/kvm/lib/kvm_util.c
index 89612535df22..bd9eb23edf3b 100644
--- a/tools/testing/selftests/kvm/lib/kvm_util.c
+++ b/tools/testing/selftests/kvm/lib/kvm_util.c
@@ -332,7 +332,7 @@ struct kvm_vm *vm_create_with_vcpus(enum vm_guest_mode mode, uint32_t nr_vcpus,
 	for (i = 0; i < nr_vcpus; ++i) {
 		uint32_t vcpuid = vcpuids ? vcpuids[i] : i;
 
-		vm_vcpu_add_default(vm, vcpuid, guest_code);
+		vm_vcpu_add(vm, vcpuid, guest_code);
 	}
 
 	return vm;
@@ -401,7 +401,7 @@ struct kvm_vcpu *vm_recreate_with_one_vcpu(struct kvm_vm *vm)
 {
 	kvm_vm_restart(vm);
 
-	return vm_vcpu_add(vm, 0);
+	return __vm_vcpu_add(vm, 0);
 }
 
 /*
@@ -1069,7 +1069,7 @@ static int vcpu_mmap_sz(void)
  * Adds a virtual CPU to the VM specified by vm with the ID given by vcpu_id.
  * No additional vCPU setup is done.  Returns the vCPU.
  */
-struct kvm_vcpu *vm_vcpu_add(struct kvm_vm *vm, uint32_t vcpu_id)
+struct kvm_vcpu *__vm_vcpu_add(struct kvm_vm *vm, uint32_t vcpu_id)
 {
 	struct kvm_vcpu *vcpu;
 
diff --git a/tools/testing/selftests/kvm/lib/riscv/processor.c b/tools/testing/selftests/kvm/lib/riscv/processor.c
index 71bd7975d65e..d0e52ec87169 100644
--- a/tools/testing/selftests/kvm/lib/riscv/processor.c
+++ b/tools/testing/selftests/kvm/lib/riscv/processor.c
@@ -286,7 +286,7 @@ struct kvm_vcpu *vm_arch_vcpu_add(struct kvm_vm *vm, uint32_t vcpu_id,
 	struct kvm_mp_state mps;
 	struct kvm_vcpu *vcpu;
 
-	vcpu = vm_vcpu_add(vm, vcpu_id);
+	vcpu = __vm_vcpu_add(vm, vcpu_id);
 	riscv_vcpu_mmu_setup(vm, vcpu_id);
 
 	/*
diff --git a/tools/testing/selftests/kvm/lib/s390x/processor.c b/tools/testing/selftests/kvm/lib/s390x/processor.c
index cf759844b226..f8170e97eeb7 100644
--- a/tools/testing/selftests/kvm/lib/s390x/processor.c
+++ b/tools/testing/selftests/kvm/lib/s390x/processor.c
@@ -170,7 +170,7 @@ struct kvm_vcpu *vm_arch_vcpu_add(struct kvm_vm *vm, uint32_t vcpu_id,
 	stack_vaddr = vm_vaddr_alloc(vm, stack_size,
 				     DEFAULT_GUEST_STACK_VADDR_MIN);
 
-	vcpu = vm_vcpu_add(vm, vcpu_id);
+	vcpu = __vm_vcpu_add(vm, vcpu_id);
 
 	/* Setup guest registers */
 	vcpu_regs_get(vm, vcpu_id, &regs);
diff --git a/tools/testing/selftests/kvm/lib/x86_64/processor.c b/tools/testing/selftests/kvm/lib/x86_64/processor.c
index 1d0c6d49b8a9..73738083456b 100644
--- a/tools/testing/selftests/kvm/lib/x86_64/processor.c
+++ b/tools/testing/selftests/kvm/lib/x86_64/processor.c
@@ -644,7 +644,7 @@ struct kvm_vcpu *vm_arch_vcpu_add(struct kvm_vm *vm, uint32_t vcpu_id,
 	stack_vaddr = vm_vaddr_alloc(vm, DEFAULT_STACK_PGS * getpagesize(),
 				     DEFAULT_GUEST_STACK_VADDR_MIN);
 
-	vcpu = vm_vcpu_add(vm, vcpu_id);
+	vcpu = __vm_vcpu_add(vm, vcpu_id);
 	vcpu_set_cpuid(vm, vcpu_id, kvm_get_supported_cpuid());
 	vcpu_setup(vm, vcpu_id);
 
diff --git a/tools/testing/selftests/kvm/set_memory_region_test.c b/tools/testing/selftests/kvm/set_memory_region_test.c
index 1274bbb0e30b..d832fc12984e 100644
--- a/tools/testing/selftests/kvm/set_memory_region_test.c
+++ b/tools/testing/selftests/kvm/set_memory_region_test.c
@@ -315,7 +315,7 @@ static void test_zero_memory_regions(void)
 	pr_info("Testing KVM_RUN with zero added memory regions\n");
 
 	vm = vm_create_barebones();
-	vcpu = vm_vcpu_add(vm, 0);
+	vcpu = __vm_vcpu_add(vm, 0);
 
 	vm_ioctl(vm, KVM_SET_NR_MMU_PAGES, (void *)64ul);
 	vcpu_run(vm, vcpu->id);
diff --git a/tools/testing/selftests/kvm/steal_time.c b/tools/testing/selftests/kvm/steal_time.c
index 1d6a91a53eae..741892cec1ea 100644
--- a/tools/testing/selftests/kvm/steal_time.c
+++ b/tools/testing/selftests/kvm/steal_time.c
@@ -282,7 +282,7 @@ int main(int ac, char **av)
 
 	/* Add the rest of the VCPUs */
 	for (i = 1; i < NR_VCPUS; ++i)
-		vm_vcpu_add_default(vm, i, guest_code);
+		vm_vcpu_add(vm, i, guest_code);
 
 	steal_time_init(vm);
 
diff --git a/tools/testing/selftests/kvm/x86_64/pmu_event_filter_test.c b/tools/testing/selftests/kvm/x86_64/pmu_event_filter_test.c
index 38f109ab0fee..e0eed19f669e 100644
--- a/tools/testing/selftests/kvm/x86_64/pmu_event_filter_test.c
+++ b/tools/testing/selftests/kvm/x86_64/pmu_event_filter_test.c
@@ -346,7 +346,7 @@ static void test_pmu_config_disable(void (*guest_code)(void))
 	cap.args[0] = KVM_PMU_CAP_DISABLE;
 	vm_enable_cap(vm, &cap);
 
-	vcpu = vm_vcpu_add_default(vm, 0, guest_code);
+	vcpu = vm_vcpu_add(vm, 0, guest_code);
 	vm_init_descriptor_tables(vm);
 	vcpu_init_descriptor_tables(vm, vcpu->id);
 
diff --git a/tools/testing/selftests/kvm/x86_64/set_boot_cpu_id.c b/tools/testing/selftests/kvm/x86_64/set_boot_cpu_id.c
index 9ba3cd4e7f20..e63709894030 100644
--- a/tools/testing/selftests/kvm/x86_64/set_boot_cpu_id.c
+++ b/tools/testing/selftests/kvm/x86_64/set_boot_cpu_id.c
@@ -92,9 +92,9 @@ static struct kvm_vm *create_vm(void)
 static void add_x86_vcpu(struct kvm_vm *vm, uint32_t vcpuid, bool bsp_code)
 {
 	if (bsp_code)
-		vm_vcpu_add_default(vm, vcpuid, guest_bsp_vcpu);
+		vm_vcpu_add(vm, vcpuid, guest_bsp_vcpu);
 	else
-		vm_vcpu_add_default(vm, vcpuid, guest_not_bsp_vcpu);
+		vm_vcpu_add(vm, vcpuid, guest_not_bsp_vcpu);
 }
 
 static void run_vm_bsp(uint32_t bsp_vcpu)
diff --git a/tools/testing/selftests/kvm/x86_64/set_sregs_test.c b/tools/testing/selftests/kvm/x86_64/set_sregs_test.c
index 8a5c1f76287c..2e67df3a95ba 100644
--- a/tools/testing/selftests/kvm/x86_64/set_sregs_test.c
+++ b/tools/testing/selftests/kvm/x86_64/set_sregs_test.c
@@ -95,7 +95,7 @@ int main(int argc, char *argv[])
 	 * the vCPU model, i.e. without doing KVM_SET_CPUID2.
 	 */
 	vm = vm_create_barebones();
-	vcpu = vm_vcpu_add(vm, 0);
+	vcpu = __vm_vcpu_add(vm, 0);
 
 	vcpu_sregs_get(vm, vcpu->id, &sregs);
 
diff --git a/tools/testing/selftests/kvm/x86_64/sev_migrate_tests.c b/tools/testing/selftests/kvm/x86_64/sev_migrate_tests.c
index 8d4b5c2f699d..f8bbfc9694ae 100644
--- a/tools/testing/selftests/kvm/x86_64/sev_migrate_tests.c
+++ b/tools/testing/selftests/kvm/x86_64/sev_migrate_tests.c
@@ -56,7 +56,7 @@ static struct kvm_vm *sev_vm_create(bool es)
 	vm = vm_create_barebones();
 	sev_ioctl(vm->fd, es ? KVM_SEV_ES_INIT : KVM_SEV_INIT, NULL);
 	for (i = 0; i < NR_MIGRATE_TEST_VCPUS; ++i)
-		vm_vcpu_add(vm, i);
+		__vm_vcpu_add(vm, i);
 	if (es)
 		start.policy |= SEV_POLICY_ES;
 	sev_ioctl(vm->fd, KVM_SEV_LAUNCH_START, &start);
@@ -75,7 +75,7 @@ static struct kvm_vm *aux_vm_create(bool with_vcpus)
 		return vm;
 
 	for (i = 0; i < NR_MIGRATE_TEST_VCPUS; ++i)
-		vm_vcpu_add(vm, i);
+		__vm_vcpu_add(vm, i);
 
 	return vm;
 }
@@ -187,7 +187,7 @@ static void test_sev_migrate_parameters(void)
 	sev_es_vm = sev_vm_create(/* es= */ true);
 	sev_es_vm_no_vmsa = vm_create_barebones();
 	sev_ioctl(sev_es_vm_no_vmsa->fd, KVM_SEV_ES_INIT, NULL);
-	vm_vcpu_add(sev_es_vm_no_vmsa, 1);
+	__vm_vcpu_add(sev_es_vm_no_vmsa, 1);
 
 	ret = __sev_migrate_from(sev_vm->fd, sev_es_vm->fd);
 	TEST_ASSERT(
@@ -288,7 +288,7 @@ static void test_sev_mirror(bool es)
 
 	/* Check that we can complete creation of the mirror VM.  */
 	for (i = 0; i < NR_MIGRATE_TEST_VCPUS; ++i)
-		vm_vcpu_add(dst_vm, i);
+		__vm_vcpu_add(dst_vm, i);
 
 	if (es)
 		sev_ioctl(dst_vm->fd, KVM_SEV_LAUNCH_UPDATE_VMSA, NULL);
diff --git a/tools/testing/selftests/kvm/x86_64/xapic_ipi_test.c b/tools/testing/selftests/kvm/x86_64/xapic_ipi_test.c
index afbbc40df884..8b366652be31 100644
--- a/tools/testing/selftests/kvm/x86_64/xapic_ipi_test.c
+++ b/tools/testing/selftests/kvm/x86_64/xapic_ipi_test.c
@@ -425,7 +425,7 @@ int main(int argc, char *argv[])
 
 	virt_pg_map(vm, APIC_DEFAULT_GPA, APIC_DEFAULT_GPA);
 
-	vm_vcpu_add_default(vm, SENDER_VCPU_ID, sender_guest_code);
+	vm_vcpu_add(vm, SENDER_VCPU_ID, sender_guest_code);
 
 	test_data_page_vaddr = vm_vaddr_alloc_page(vm);
 	data =
diff --git a/tools/testing/selftests/kvm/x86_64/tsc_scaling_sync.c b/tools/testing/selftests/kvm/x86_64/tsc_scaling_sync.c
index ea70ca2e63c3..2411215e7ae8 100644
--- a/tools/testing/selftests/kvm/x86_64/tsc_scaling_sync.c
+++ b/tools/testing/selftests/kvm/x86_64/tsc_scaling_sync.c
@@ -51,10 +51,10 @@ static void *run_vcpu(void *_cpu_nr)
 	static bool first_cpu_done;
 	struct kvm_vcpu *vcpu;
 
 	/* The kernel is fine, but vm_vcpu_add_default() needs locking */
 	pthread_spin_lock(&create_lock);
 
-	vcpu = vm_vcpu_add_default(vm, vcpu_id, guest_code);
+	vcpu = vm_vcpu_add(vm, vcpu_id, guest_code);
 
 	if (!first_cpu_done) {
 		first_cpu_done = true;
@@ -51,10 +51,10 @@ static void *run_vcpu(void *_cpu_nr)
 	struct kvm_vcpu *vcpu;
 
-	/* The kernel is fine, but vm_vcpu_add_default() needs locking */
+	/* The kernel is fine, but vm_vcpu_add() needs locking */
 	pthread_spin_lock(&create_lock);
 
-- 
2.36.0.464.gb9c8b46e94-goog


  parent reply	other threads:[~2022-05-04 22:55 UTC|newest]

Thread overview: 131+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2022-05-04 22:47 [PATCH 000/128] KVM: selftests: Overhaul APIs, purge VCPU_ID Sean Christopherson
2022-05-04 22:47 ` [PATCH 001/128] KVM: selftests: Fix buggy-but-benign check in test_v3_new_redist_regions() Sean Christopherson
2022-05-04 22:47 ` [PATCH 002/128] KVM: selftests: Drop stale declarations from kvm_util_base.h Sean Christopherson
2022-05-04 22:47 ` [PATCH 003/128] KVM: selftests: Unconditionally compile KVM selftests with -Werror Sean Christopherson
2022-05-05 14:08   ` Vitaly Kuznetsov
2022-05-06 21:37     ` Sean Christopherson
2022-05-04 22:47 ` [PATCH 004/128] KVM: selftests: Always open VM file descriptors with O_RDWR Sean Christopherson
2022-05-04 22:47 ` [PATCH 005/128] KVM: selftests: Add another underscore to inner ioctl() helpers Sean Christopherson
2022-05-04 22:47 ` [PATCH 006/128] KVM: selftests: Make vcpu_ioctl() a wrapper to pretty print ioctl name Sean Christopherson
2022-05-04 22:47 ` [PATCH 007/128] KVM: selftests: Drop @mode from common vm_create() helper Sean Christopherson
2022-05-04 22:47 ` [PATCH 008/128] KVM: selftests: Split vcpu_set_nested_state() into two helpers Sean Christopherson
2022-05-04 22:47 ` [PATCH 009/128] KVM: sefltests: Use vcpu_ioctl() and __vcpu_ioctl() helpers Sean Christopherson
2022-05-04 22:47 ` [PATCH 010/128] KVM: selftests: Add __vcpu_run() helper Sean Christopherson
2022-05-04 22:47 ` [PATCH 011/128] KVM: selftests: Use vcpu_access_device_attr() in arm64 code Sean Christopherson
2022-05-04 22:47 ` [PATCH 012/128] KVM: selftests: Remove vcpu_get_fd() Sean Christopherson
2022-05-04 22:47 ` [PATCH 013/128] KVM: selftests: Add vcpu_get() to retrieve and assert on vCPU existence Sean Christopherson
2022-05-04 22:47 ` [PATCH 014/128] KVM: selftests: Make vm_ioctl() a wrapper to pretty print ioctl name Sean Christopherson
2022-05-04 22:47 ` [PATCH 015/128] KVM: sefltests: Use vm_ioctl() and __vm_ioctl() helpers Sean Christopherson
2022-05-04 22:47 ` [PATCH 016/128] KVM: selftests: Make kvm_ioctl() a wrapper to pretty print ioctl name Sean Christopherson
2022-05-04 22:47 ` [PATCH 017/128] KVM: selftests: Use kvm_ioctl() helpers Sean Christopherson
2022-05-04 22:47 ` [PATCH 018/128] KVM: selftests: Use __KVM_SYSCALL_ERROR() to handle non-KVM syscall errors Sean Christopherson
2022-05-04 22:47 ` [PATCH 019/128] KVM: selftests: Make x86-64's register dump helpers static Sean Christopherson
2022-05-04 22:47 ` [PATCH 020/128] KVM: selftests: Get rid of kvm_util_internal.h Sean Christopherson
2022-05-04 22:47 ` [PATCH 021/128] KVM: selftests: Use KVM_IOCTL_ERROR() for one-off arm64 ioctls Sean Christopherson
2022-05-04 22:47 ` [PATCH 022/128] KVM: selftests: Drop @test param from kvm_create_device() Sean Christopherson
2022-05-04 22:47 ` [PATCH 023/128] KVM: selftests: Move KVM_CREATE_DEVICE_TEST code to separate helper Sean Christopherson
2022-05-04 22:47 ` [PATCH 024/128] KVM: selftests: Multiplex return code and fd in __kvm_create_device() Sean Christopherson
2022-05-04 22:47 ` [PATCH 025/128] KVM: selftests: Rename KVM_HAS_DEVICE_ATTR helpers for consistency Sean Christopherson
2022-05-04 22:47 ` [PATCH 026/128] KVM: selftests: Drop 'int' return from asserting *_has_device_attr() Sean Christopherson
2022-05-04 22:47 ` [PATCH 027/128] KVM: selftests: Split get/set device_attr helpers Sean Christopherson
2022-05-04 22:47 ` [PATCH 028/128] KVM: selftests: Add a VM backpointer to 'struct vcpu' Sean Christopherson
2022-05-04 22:47 ` [PATCH 029/128] KVM: selftests: Add vm_create_*() variants to expose/return " Sean Christopherson
2022-05-04 22:47 ` [PATCH 030/128] KVM: selftests: Push vm_adjust_num_guest_pages() into "w/o vCPUs" helper Sean Christopherson
2022-05-04 22:47 ` [PATCH 031/128] KVM: selftests: Use vm_create_without_vcpus() in set_boot_cpu_id Sean Christopherson
2022-05-04 22:47 ` [PATCH 032/128] KVM: selftests: Use vm_create_without_vcpus() in dirty_log_test Sean Christopherson
2022-05-04 22:47 ` [PATCH 033/128] KVM: selftests: Use vm_create_without_vcpus() in hardware_disable_test Sean Christopherson
2022-05-04 22:47 ` [PATCH 034/128] KVM: selftests: Use vm_create_without_vcpus() in psci_cpu_on_test Sean Christopherson
2022-05-04 22:47 ` [PATCH 035/128] KVM: selftests: Rename vm_create() => vm_create_barebones(), drop param Sean Christopherson
2022-05-04 22:47 ` [PATCH 036/128] KVM: selftests: Rename vm_create_without_vcpus() => vm_create() Sean Christopherson
2022-05-04 22:47 ` [PATCH 037/128] KVM: selftests: Make vm_create() a wrapper that specifies VM_MODE_DEFAULT Sean Christopherson
2022-05-04 22:47 ` [PATCH 038/128] KVM: selftests: Rename xAPIC state test's vcpu struct Sean Christopherson
2022-05-04 22:47 ` [PATCH 039/128] KVM: selftests: Rename vcpu.state => vcpu.run Sean Christopherson
2022-05-04 22:47 ` [PATCH 040/128] KVM: selftests: Rename 'struct vcpu' to 'struct kvm_vcpu' Sean Christopherson
2022-05-04 22:47 ` [PATCH 041/128] KVM: selftests: Return the created vCPU from vm_vcpu_add() Sean Christopherson
2022-05-04 22:47 ` [PATCH 042/128] KVM: selftests: Convert memslot_perf_test away from VCPU_ID Sean Christopherson
2022-05-04 22:47 ` [PATCH 043/128] KVM: selftests: Convert rseq_test " Sean Christopherson
2022-05-04 22:47 ` [PATCH 044/128] KVM: selftests: Convert xss_msr_test " Sean Christopherson
2022-05-04 22:47 ` [PATCH 045/128] KVM: selftests: Convert vmx_preemption_timer_test " Sean Christopherson
2022-05-04 22:47 ` [PATCH 046/128] KVM: selftests: Convert vmx_pmu_msrs_test " Sean Christopherson
2022-05-04 22:47 ` [PATCH 047/128] KVM: selftests: Convert vmx_set_nested_state_test " Sean Christopherson
2022-05-04 22:47 ` [PATCH 048/128] KVM: selftests: Convert vmx_tsc_adjust_test " Sean Christopherson
2022-05-04 22:47 ` [PATCH 049/128] KVM: selftests: Convert mmu_role_test " Sean Christopherson
2022-05-04 22:47 ` [PATCH 050/128] KVM: selftests: Convert pmu_event_filter_test " Sean Christopherson
2022-05-04 22:47 ` [PATCH 051/128] KVM: selftests: Convert smm_test " Sean Christopherson
2022-05-04 22:47 ` [PATCH 052/128] KVM: selftests: Convert state_test " Sean Christopherson
2022-05-04 22:47 ` [PATCH 053/128] KVM: selftests: Convert svm_int_ctl_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 054/128] KVM: selftests: Convert svm_vmcall_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 055/128] KVM: selftests: Convert sync_regs_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 056/128] KVM: selftests: Convert hyperv_cpuid " Sean Christopherson
2022-05-04 22:48 ` [PATCH 057/128] KVM: selftests: Convert kvm_pv_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 058/128] KVM: selftests: Convert platform_info_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 059/128] KVM: selftests: Convert vmx_nested_tsc_scaling_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 060/128] KVM: selftests: Convert set_sregs_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 061/128] KVM: selftests: Convert vmx_dirty_log_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 062/128] KVM: selftests: Convert vmx_close_while_nested_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 063/128] KVM: selftests: Convert vmx_apic_access_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 064/128] KVM: selftests: Convert userspace_msr_exit_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 065/128] KVM: selftests: Convert vmx_exception_with_invalid_guest_state " Sean Christopherson
2022-05-04 22:48 ` [PATCH 066/128] KVM: selftests: Convert tsc_msrs_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 067/128] KVM: selftests: Convert kvm_clock_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 068/128] KVM: selftests: Convert hyperv_svm_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 069/128] KVM: selftests: Convert hyperv_features " Sean Christopherson
2022-05-04 22:48 ` [PATCH 070/128] KVM: selftests: Convert hyperv_clock " Sean Christopherson
2022-05-04 22:48 ` [PATCH 071/128] KVM: selftests: Convert evmcs_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 072/128] KVM: selftests: Convert emulator_error_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 073/128] KVM: selftests: Convert debug_regs " Sean Christopherson
2022-05-04 22:48 ` [PATCH 074/128] KVM: selftests: Add proper helper for advancing RIP in debug_regs Sean Christopherson
2022-05-04 22:48 ` [PATCH 075/128] KVM: selftests: Convert amx_test away from VCPU_ID Sean Christopherson
2022-05-04 22:48 ` [PATCH 076/128] KVM: selftests: Convert cr4_cpuid_sync_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 077/128] KVM: selftests: Convert cpuid_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 078/128] KVM: selftests: Convert userspace_io_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 079/128] KVM: selftests: Convert vmx_invalid_nested_guest_state " Sean Christopherson
2022-05-04 22:48 ` [PATCH 080/128] KVM: selftests: Convert xen_vmcall_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 081/128] KVM: selftests: Convert xen_shinfo_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 082/128] KVM: selftests: Convert dirty_log_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 083/128] KVM: selftests: Convert set_memory_region_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 084/128] KVM: selftests: Convert system_counter_offset_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 085/128] KVM: selftests: Track kvm_vcpu object in tsc_scaling_sync Sean Christopherson
2022-05-04 22:48 ` [PATCH 086/128] KVM: selftests: Convert xapic_state_test away from hardcoded vCPU ID Sean Christopherson
2022-05-04 22:48 ` [PATCH 087/128] KVM: selftests: Convert debug-exceptions away from VCPU_ID Sean Christopherson
2022-05-04 22:48 ` [PATCH 088/128] KVM: selftests: Convert fix_hypercall_test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 089/128] KVM: selftests: Convert vgic_irq " Sean Christopherson
2022-05-04 22:48 ` [PATCH 090/128] KVM: selftests: Make arm64's guest_get_vcpuid() declaration arm64-only Sean Christopherson
2022-05-04 22:48 ` [PATCH 091/128] KVM: selftests: Move vm_is_unrestricted_guest() to x86-64 Sean Christopherson
2022-05-04 22:48 ` [PATCH 092/128] KVM: selftests: Add "arch" to common utils that have arch implementations Sean Christopherson
2022-05-04 22:48 ` [PATCH 093/128] KVM: selftests: Return created vcpu from vm_vcpu_add_default() Sean Christopherson
2022-05-04 22:48 ` Sean Christopherson [this message]
2022-05-04 22:48 ` [PATCH 095/128] KVM: selftests: Convert set_boot_cpu_id away from global VCPU_IDs Sean Christopherson
2022-05-04 22:48 ` [PATCH 096/128] KVM: selftests: Convert psci_cpu_on_test away from VCPU_ID Sean Christopherson
2022-05-04 22:48 ` [PATCH 097/128] KVM: selftests: Convert hardware_disable_test to pass around vCPU objects Sean Christopherson
2022-05-04 22:48 ` [PATCH 098/128] KVM: selftests: Add VM creation helper that "returns" vCPUs Sean Christopherson
2022-05-04 22:48 ` [PATCH 099/128] KVM: selftests: Convert steal_time away from VCPU_ID Sean Christopherson
2022-05-04 22:48 ` [PATCH 100/128] KVM: selftests: Convert arch_timer " Sean Christopherson
2022-05-04 22:48 ` [PATCH 101/128] KVM: selftests: Fix typo in vgic_init test Sean Christopherson
2022-05-04 22:48 ` [PATCH 102/128] KVM: selftests: Convert vgic_init away from vm_create_default_with_vcpus() Sean Christopherson
2022-05-04 22:48 ` [PATCH 103/128] KVM: selftests: Convert xapic_ipi_test away from *_VCPU_ID Sean Christopherson
2022-05-04 22:48 ` [PATCH 104/128] KVM: selftests: Convert sync_regs_test away from VCPU_ID Sean Christopherson
2022-05-04 22:48 ` [PATCH 105/128] KVM: selftests: Convert s390's "resets" test " Sean Christopherson
2022-05-04 22:48 ` [PATCH 106/128] KVM: selftests: Convert memop " Sean Christopherson
2022-05-04 22:48 ` [PATCH 107/128] KVM: selftests: Convert s390x/diag318_test_handler " Sean Christopherson
2022-05-04 22:48 ` [PATCH 108/128] KVM: selftests: Convert tprot " Sean Christopherson
2022-05-04 22:48 ` [PATCH 109/128] KVM: selftests: Use vm_create() in tsc_scaling_sync Sean Christopherson
2022-05-04 22:48 ` [PATCH 110/128] KVM: selftests: Use vm_create_with_vcpus() in max_guest_memory_test Sean Christopherson
2022-05-04 22:48 ` [PATCH 111/128] KVM: selftests: Drop vm_create_default* helpers Sean Christopherson
2022-05-04 22:48 ` [PATCH 112/128] KVM: selftests: Drop @vcpuids param from VM creators Sean Christopherson
2022-05-04 22:48 ` [PATCH 113/128] KVM: selftests: Convert kvm_page_table_test away from reliance on vcpu_id Sean Christopherson
2022-05-04 22:49 ` [PATCH 114/128] KVM: selftests: Convert kvm_binary_stats_test away from vCPU IDs Sean Christopherson
2022-05-04 22:49 ` [PATCH 115/128] KVM: selftests: Convert get-reg-list away from its "VCPU_ID" Sean Christopherson
2022-05-04 22:49 ` [PATCH 116/128] KVM: selftests: Stop hardcoding vCPU IDs in vcpu_width_config Sean Christopherson
2022-05-04 22:49 ` [PATCH 117/128] KVM: selftests: Stop conflating vCPU index and ID in perf tests Sean Christopherson
2022-05-04 22:49 ` [PATCH 118/128] KVM: selftests: Remove vcpu_get() usage from dirty_log_test Sean Christopherson
2022-05-04 22:49 ` [PATCH 119/128] KVM: selftests: Require vCPU output array when creating VM with vCPUs Sean Christopherson
2022-05-04 22:49 ` [PATCH 121/128] KVM: selftests: Drop vcpu_get(), rename vcpu_find() => vcpu_exists() Sean Christopherson
2022-05-04 22:49 ` [PATCH 122/128] KVM: selftests: Remove vcpu_state() helper Sean Christopherson
2022-05-04 22:49 ` [PATCH 123/128] KVM: selftests: Open code and drop 'struct kvm_vm' accessors Sean Christopherson
2022-05-04 22:49 ` [PATCH 124/128] KVM: selftests: Drop @slot0_mem_pages from __vm_create_with_vcpus() Sean Christopherson
2022-05-04 22:49 ` [PATCH 125/128] KVM: selftests: Drop @num_percpu_pages " Sean Christopherson
2022-05-04 22:49 ` [PATCH 126/128] KVM: selftests: Move per-VM/per-vCPU nr pages calculation to __vm_create() Sean Christopherson
2022-05-04 22:49 ` [PATCH 127/128] KVM: selftests: Trust that MAXPHYADDR > memslot0 in vmx_apic_access_test Sean Christopherson
2022-05-04 22:49 ` [PATCH 128/128] KVM: selftests: Drop DEFAULT_GUEST_PHY_PAGES, open code the magic number Sean Christopherson
2022-05-05 14:26 ` [PATCH 000/128] KVM: selftests: Overhaul APIs, purge VCPU_ID Vitaly Kuznetsov

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20220504224914.1654036-95-seanjc@google.com \
    --to=seanjc@google.com \
    --cc=bgardon@google.com \
    --cc=dmatlack@google.com \
    --cc=drjones@redhat.com \
    --cc=kvm@vger.kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=oupton@google.com \
    --cc=pbonzini@redhat.com \
    --cc=vkuznets@redhat.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox